#ifndef INC_Vrml97ParserTokenTypes_hpp_
#define INC_Vrml97ParserTokenTypes_hpp_

/* $ANTLR 2.7.4: "Vrml97Parser.g" -> "Vrml97ParserTokenTypes.hpp"$ */

#ifndef CUSTOM_API
# define CUSTOM_API
#endif

#ifdef __cplusplus
struct CUSTOM_API Vrml97ParserTokenTypes {
#endif
	enum {
		EOF_ = 1,
		PERIOD = 4,
		LBRACKET = 5,
		RBRACKET = 6,
		LBRACE = 7,
		RBRACE = 8,
		ID = 9,
		INTEGER = 10,
		HEX_INTEGER = 11,
		REAL = 12,
		STRING = 13,
		KEYWORD_DEF = 14,
		KEYWORD_EVENTIN = 15,
		KEYWORD_EVENTOUT = 16,
		KEYWORD_EXPOSEDFIELD = 17,
		KEYWORD_EXTERNPROTO = 18,
		KEYWORD_FALSE = 19,
		KEYWORD_FIELD = 20,
		KEYWORD_IS = 21,
		KEYWORD_NULL = 22,
		KEYWORD_PROTO = 23,
		KEYWORD_ROUTE = 24,
		KEYWORD_TO = 25,
		KEYWORD_TRUE = 26,
		KEYWORD_USE = 27,
		FIELDTYPE_SFBOOL = 28,
		FIELDTYPE_SFCOLOR = 29,
		FIELDTYPE_SFFLOAT = 30,
		FIELDTYPE_SFIMAGE = 31,
		FIELDTYPE_SFINT32 = 32,
		FIELDTYPE_SFNODE = 33,
		FIELDTYPE_SFROTATION = 34,
		FIELDTYPE_SFSTRING = 35,
		FIELDTYPE_SFTIME = 36,
		FIELDTYPE_SFVEC2F = 37,
		FIELDTYPE_SFVEC3F = 38,
		FIELDTYPE_MFCOLOR = 39,
		FIELDTYPE_MFFLOAT = 40,
		FIELDTYPE_MFINT32 = 41,
		FIELDTYPE_MFNODE = 42,
		FIELDTYPE_MFROTATION = 43,
		FIELDTYPE_MFSTRING = 44,
		FIELDTYPE_MFTIME = 45,
		FIELDTYPE_MFVEC2F = 46,
		FIELDTYPE_MFVEC3F = 47,
		NULL_TREE_LOOKAHEAD = 3
	};
#ifdef __cplusplus
};
#endif
#endif /*INC_Vrml97ParserTokenTypes_hpp_*/
